Classification
======================

.. toctree::
    :caption: Contents
    :maxdepth: 2

    cct
    cross
    cvt
    pyramid
    swin
    vanilla
    visformer
    convit
    convvt
    vivit
    perceiver_io
